{% load i18n %} {% load common_filters %} {% load common_tags %} {% comment %} {% endcomment %}
{% comment %}
{% endcomment %}
{% if controller.day_items_size %}

{% trans "Object" %} | {% trans "Name" %} | {% trans "Date" %} | {% trans "Link" %}
--- | --- | --- | ---
{% for i in controller.day_items %} {% for c in i.project %}
| {{ c.name|truncatebefor:"65" }} | {{ c.getDate }} | {% trans "Browse" %}
{% endfor %} {% for c in i.screen %}
| {{ c.name|truncatebefor:"65" }} | {{ c.getDate }} | {% trans "Browse" %}
{% endfor %} {% for c in i.dataset %}
| {{ c.name|truncatebefor:"65" }} | {{ c.getDate }} | {% trans "Browse" %}
{% endfor %} {% for c in i.plate %}
| {{ c.name|truncatebefor:"65" }} | {{ c.getDate }} | {% trans "Browse" %}
{% endfor %} {% for c in i.image %}
| {{ c.name|truncatebefor:"65" }} | {{ c.getDate }} | {% trans "Browse" %}
{% endfor %} {% endfor %}

{% else %}

{% trans "No data." %}

{% endif %} {% include "webclient/history/history_paging.html" %}